==> aroundme_0_5_0.zip: aroundme_0_5_0/aroundme/template/barnraiser_01/sn_profile.tpl.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of aroundme
// 
// Copyright (C) 2003, 2005 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
// 
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
// 
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
// 
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
// 02111-1307, USA.
// -----------------------------------------------------------------------

?>


<form action="sn_profile.php" method="post">
<input type="hidden" name="user_id" value="<?php echo $profile['user_id'];?>" />

<table width="100%" border="0" cellspacing="0" cellpadding="0">
	<tr>
		<td width="180" valign="top">
			<?php
			include $templatePath . "sn_menu.inc.tpl.php";
			?>
		</td>

		<td width="20">&nbsp;</td>


		<td width="560" valign="top">
			<div class="box_top">
				<?php echo $lang['hdr_summary'];?><br />
			</div>
			
			<div class="box_mid" style="padding: 9px;">
			<?php
			if (isset($display) && $display == "block") {
			?>

			<table border="0" cellspacing="0" cellpadding="4" width="100%">
				<tr>
					<td colspan="2">
						<b><?php echo $lang['hdr_block'];?></b><br />
					</td>
				</tr>
				<tr>
					<td>
						<?php echo $lang['txt_block_description_text'];?><br />
					</td>
					<td>
						<textarea rows="3" cols="25" name="data[block_description]" class="formInput"></textarea><br />
					</td>
				</tr>
				<tr>
					<td align="right" colspan="2">
						<input type="submit" name="set_block" value="<?php echo $lang['sub_block'];?>" class="button_urgent" /><br />
						<br />
					</td>
				</tr>
			</table>
			
			<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="10" alt="" /><br />
			<?php }?>
			
			<table width="100%" cellpadding="4" cellspacing="0" border="0">
				<tr>
					<td valign="top">
						<?php echo $profile['profile_summary'];?><br />
					</td>
				</tr>
			</table>
			
			<hr />
			<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="3" alt="" /><br />
			
			<?php
			if (isset($relationship_paths)) {
			?>
			<table width="100%" cellpadding="4" cellspacing="0" border="0">
				<tr>
					<td>
						<b><?php echo $lang['hdr_relationship'];?></b><br />
					</td>
				</tr>
				<?php
				foreach($relationship_paths as $key => $r):
				?>
				<tr>
					<td>
						<table cellpadding="0" cellspacing="4" border="0">
							<tr>
								<?php
								foreach($r['relation'] as $key1 => $i):
								?>
								<td>
									<?php 
									if ($i == $me['user_id']) {
									    echo "me<br />";
									}
									else {
										foreach($relationship_profiles as $keyrp => $rp):
											if ($i == $rp['user_id']) {
												
												if (count($r['relation']) > $key1+1) {
													echo "<a href=\"sn_profile.php?user_id=" . $rp['user_id'] . "\">" . $rp['profile_nic'] . "</a><br />";
												}
												else {
													echo $rp['profile_nic'] . "<br />";
												}
												
												break;
											}
										endforeach;
									}
									?>
								</td>
								<?php
								if (count($r['relation']) > $key1+1) {
									echo "<td>-&#62;<br /></td>";
								}
								?>
								<?php 
								endforeach;
								?>
							</tr>
						</table>
					</td>
				</tr>
				<?php
				endforeach;
				?>
			</table>
			
			<hr />
			<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="3" alt="" /><br />
			<?php }?>
				
			<table width="100%" cellpadding="4" cellspacing="0" border="0">
				<tr>
					<td colspan="2">
						<b><?php echo $lang['hdr_contact'];?></b><br />
					</td>
				</tr>
				<?php
				if (!empty($lang['txt_profile_text1'])) {
				?>
				<tr>
					<td>
						<?php echo $lang['txt_profile_text1'];?><br />
					</td>
					<td>
						<?php echo $profile['profile_text1'];?><br />
					</td>
				</tr>
				<?php }?>
				
				<?php
				if (!empty($lang['txt_profile_text2'])) {
				?>
				<tr>
					<td>
						<?php echo $lang['txt_profile_text2'];?><br />
					</td>
					<td>
						<?php echo $profile['profile_text2'];?><br />
					</td>
				</tr>
				<?php }?>
				
				<?php
				if (!empty($lang['txt_profile_text3'])) {
				?>
				<tr>
					<td>
						<?php echo $lang['txt_profile_text3'];?><br />
					</td>
					<td>
						<?php echo $profile['profile_text3'];?><br />
					</td>
				</tr>
				<?php }?>
				
				<?php
				if (!empty($lang['txt_profile_text4'])) {
				?>
				<tr>
					<td>
						<?php echo $lang['txt_profile_text4'];?><br />
					</td>
					<td>
						<?php echo $profile['profile_text4'];?><br />
					</td>
				</tr>
				<?php }?>
				
				<?php
				if (!empty($lang['txt_profile_text5'])) {
				?>
				<tr>
					<td>
						<?php echo $lang['txt_profile_text5'];?><br />
					</td>
					<td>
						<?php echo $profile['profile_text5'];?><br />
					</td>
				</tr>
				<?php }?>
				
				<?php
				if (!empty($lang['txt_profile_text6'])) {
				?>
				<tr>
					<td>
						<?php echo $lang['txt_profile_text6'];?><br />
					</td>
					<td>
						<?php echo $profile['profile_text6'];?><br />
					</td>
				</tr>
				<?php }?>
				
				<?php
				if (!empty($lang['txt_profile_text7'])) {
				?>
				<tr>
					<td>
						<?php echo $lang['txt_profile_text7'];?><br />
					</td>
					<td>
						<?php echo $profile['profile_text7'];?><br />
					</td>
				</tr>
				<?php }?>
				
				<?php
				if (!empty($lang['txt_profile_text8'])) {
				?>
				<tr>
					<td>
						<?php echo $lang['txt_profile_text8'];?><br />
					</td>
					<td>
						<?php echo $profile['profile_text8'];?><br />
					</td>
				</tr>
				<?php }?>
				
				<?php
				if (!empty($lang['txt_profile_text9'])) {
				?>
				<tr>
					<td>
						<?php echo $lang['txt_profile_text9'];?><br />
					</td>
					<td>
						<?php echo $profile['profile_text9'];?><br />
					</td>
				</tr>
				<?php }?>
				
				<?php
				if (!empty($lang['txt_profile_text10'])) {
				?>
				<tr>
					<td>
						<?php echo $lang['txt_profile_text10'];?><br />
					</td>
					<td>
						<?php echo $profile['profile_text10'];?><br />
					</td>
				</tr>
				<?php }?>
			</table>
			</div>
			
			<div id="box_bottom">
				<table cellpadding="0" cellspacing="0" border="0" width="100%">
					<tr>
						<td align="left">
							<img src="<?php echo $templatePath;?>img/box_bottom_left.png" width="5" height="18" alt="" border="0" /><br />
						</td>
						<td align="left">
							<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="9" alt="" border="0" /><br />
						</td>
						<td align="right">
							<img src="<?php echo $templatePath;?>img/box_bottom_right.png" width="5" height="18" alt="" border="0" /><br />
						</td>
					</tr>
				</table>
			</div>
		</td>
	</tr>
</table>
</form>

==> aroundme_0_5_2.zip: aroundme_0_5_2/aroundme/template/barnraiser_01/sn_profile.tpl.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of aroundme
// 
// Copyright (C) 2003, 2005 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
// 
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
// 
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
// 
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
// 02111-1307, USA.
// -----------------------------------------------------------------------

?>


<form action="sn_profile.php" method="post">
<input type="hidden" name="user_id" value="<?php echo $profile['user_id'];?>" />

<table width="100%" border="0" cellspacing="0" cellpadding="0">
	<tr>
		<td width="180" valign="top">
			<?php
			include $templatePath . "sn_menu.inc.tpl.php";
			?>
			
			<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="9" alt="" /><br />
			
			<?php
			$hidden_form = array(
				"item_id" => $profile['user_id']
			);
			
			include $templatePath . "tag.inc.tpl.php";?>
		</td>

		<td width="20">&nbsp;</td>


		<td width="560" valign="top">
			<div class="box_top">
				<?php echo $lang['hdr_summary'];?><br />
			</div>
			
			<div class="box_mid" style="padding: 9px;">
			<?php
			if (isset($display) && $display == "block") {
			?>

			<table border="0" cellspacing="0" cellpadding="4" width="100%">
				<tr>
					<td colspan="2">
						<b><?php echo $lang['hdr_block'];?></b><br />
					</td>
				</tr>
				<tr>
					<td>
						<?php echo $lang['txt_block_description_text'];?><br />
					</td>
					<td>
						<textarea rows="3" cols="25" name="data[block_description]" class="formInput"></textarea><br />
					</td>
				</tr>
				<tr>
					<td align="right" colspan="2">
						<input type="submit" name="set_block" value="<?php echo $lang['sub_block'];?>" class="button_urgent" /><br />
						<br />
					</td>
				</tr>
			</table>
			
			<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="9" alt="" /><br />
			<?php }?>
			
			<table width="100%" cellpadding="4" cellspacing="0" border="0">
				<tr>
					<td valign="top">
						<?php echo $profile['profile_summary'];?><br />
					</td>
				</tr>
			</table>
			
			</div>
			
			<div id="box_bottom">
				<table cellpadding="0" cellspacing="0" border="0" width="100%">
					<tr>
						<td align="left">
							<img src="<?php echo $templatePath;?>img/box_bottom_left.png" width="5" height="18" alt="" border="0" /><br />
						</td>
						<td align="left">
							<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="9" alt="" border="0" /><br />
						</td>
						<td align="right">
							<img src="<?php echo $templatePath;?>img/box_bottom_right.png" width="5" height="18" alt="" border="0" /><br />
						</td>
					</tr>
				</table>
			</div>
			
			
			
			<?php
			if (isset($relationship_paths)) {
			?>
			<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="9" alt="" /><br />
			
			<div class="box_top">
				<?php echo $lang['hdr_relationship'];?><br />
			</div>
			
			<div class="box_mid" style="padding: 9px;">
			<table width="100%" cellpadding="4" cellspacing="0" border="0">
				<?php
				foreach($relationship_paths as $key => $r):
				?>
				<tr>
					<td>
						<table cellpadding="0" cellspacing="4" border="0">
							<tr>
								<?php
								foreach($r['relation'] as $key1 => $i):
								?>
								<td>
									<?php 
									if ($i == $me['user_id']) {
									    echo "me<br />";
									}
									else {
										foreach($relationship_profiles as $keyrp => $rp):
											if ($i == $rp['user_id']) {
												
												if (count($r['relation']) > $key1+1) {
													echo "<a href=\"sn_profile.php?user_id=" . $rp['user_id'] . "\">" . $rp['profile_nic'] . "</a><br />";
												}
												else {
													echo $rp['profile_nic'] . "<br />";
												}
												
												break;
											}
										endforeach;
									}
									?>
								</td>
								<?php
								if (count($r['relation']) > $key1+1) {
									echo "<td>-&#62;<br /></td>";
								}
								?>
								<?php 
								endforeach;
								?>
							</tr>
						</table>
					</td>
				</tr>
				<?php
				endforeach;
				?>
			</table>
			</div>
			
			<div id="box_bottom">
				<table cellpadding="0" cellspacing="0" border="0" width="100%">
					<tr>
						<td align="left">
							<img src="<?php echo $templatePath;?>img/box_bottom_left.png" width="5" height="18" alt="" border="0" /><br />
						</td>
						<td align="left">
							<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="9" alt="" border="0" /><br />
						</td>
						<td align="right">
							<img src="<?php echo $templatePath;?>img/box_bottom_right.png" width="5" height="18" alt="" border="0" /><br />
						</td>
					</tr>
				</table>
			</div>
			<?php }?>
			
			
			<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="9" alt="" /><br />
			
			<div class="box_top">
				<?php echo $lang['hdr_contact'];?><br />
			</div>
			
			<div class="box_mid" style="padding: 9px;">
			<table width="100%" cellpadding="4" cellspacing="0" border="0">
				<?php
				if (!empty($lang['txt_profile_text1'])) {
				?>
				<tr>
					<td>
						<?php echo $lang['txt_profile_text1'];?><br />
					</td>
					<td>
						<?php echo $profile['profile_text1'];?><br />
					</td>
				</tr>
				<?php }?>
				
				<?php
				if (!empty($lang['txt_profile_text2'])) {
				?>
				<tr>
					<td>
						<?php echo $lang['txt_profile_text2'];?><br />
					</td>
					<td>
						<?php echo $profile['profile_text2'];?><br />
					</td>
				</tr>
				<?php }?>
				
				<?php
				if (!empty($lang['txt_profile_text3'])) {
				?>
				<tr>
					<td>
						<?php echo $lang['txt_profile_text3'];?><br />
					</td>
					<td>
						<?php echo $profile['profile_text3'];?><br />
					</td>
				</tr>
				<?php }?>
				
				<?php
				if (!empty($lang['txt_profile_text4'])) {
				?>
				<tr>
					<td>
						<?php echo $lang['txt_profile_text4'];?><br />
					</td>
					<td>
						<?php echo $profile['profile_text4'];?><br />
					</td>
				</tr>
				<?php }?>
				
				<?php
				if (!empty($lang['txt_profile_text5'])) {
				?>
				<tr>
					<td>
						<?php echo $lang['txt_profile_text5'];?><br />
					</td>
					<td>
						<?php echo $profile['profile_text5'];?><br />
					</td>
				</tr>
				<?php }?>
				
				<?php
				if (!empty($lang['txt_profile_text6'])) {
				?>
				<tr>
					<td>
						<?php echo $lang['txt_profile_text6'];?><br />
					</td>
					<td>
						<?php echo $profile['profile_text6'];?><br />
					</td>
				</tr>
				<?php }?>
				
				<?php
				if (!empty($lang['txt_profile_text7'])) {
				?>
				<tr>
					<td>
						<?php echo $lang['txt_profile_text7'];?><br />
					</td>
					<td>
						<?php echo $profile['profile_text7'];?><br />
					</td>
				</tr>
				<?php }?>
				
				<?php
				if (!empty($lang['txt_profile_text8'])) {
				?>
				<tr>
					<td>
						<?php echo $lang['txt_profile_text8'];?><br />
					</td>
					<td>
						<?php echo $profile['profile_text8'];?><br />
					</td>
				</tr>
				<?php }?>
				
				<?php
				if (!empty($lang['txt_profile_text9'])) {
				?>
				<tr>
					<td>
						<?php echo $lang['txt_profile_text9'];?><br />
					</td>
					<td>
						<?php echo $profile['profile_text9'];?><br />
					</td>
				</tr>
				<?php }?>
				
				<?php
				if (!empty($lang['txt_profile_text10'])) {
				?>
				<tr>
					<td>
						<?php echo $lang['txt_profile_text10'];?><br />
					</td>
					<td>
						<?php echo $profile['profile_text10'];?><br />
					</td>
				</tr>
				<?php }?>
			</table>
			</div>
			
			<div id="box_bottom">
				<table cellpadding="0" cellspacing="0" border="0" width="100%">
					<tr>
						<td align="left">
							<img src="<?php echo $templatePath;?>img/box_bottom_left.png" width="5" height="18" alt="" border="0" /><br />
						</td>
						<td align="left">
							<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="9" alt="" border="0" /><br />
						</td>
						<td align="right">
							<img src="<?php echo $templatePath;?>img/box_bottom_right.png" width="5" height="18" alt="" border="0" /><br />
						</td>
					</tr>
				</table>
			</div>
			
			
			<?php
			if (isset($groups)) {
			?>
			<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="9" alt="" /><br />
			
			<div class="box_top">
				<?php echo $lang['hdr_groups'];?><br />
			</div>
			
			<div class="box_mid" style="padding: 9px;">
			<table width="100%" cellpadding="4" cellspacing="0" border="0">
			    <?php
				foreach($groups as $key => $i):
				?>
				<tr>
					<td valign="top">
						<a href="g_group.php?group_id=<?php echo $i['group_id'];?>"><?php echo $i['group_title'];?></a><br />
					</td>
					<td valign="top">
						<?php echo $i['group_synopsis'];?><br />
					</td>
				</tr>
				<?php
				endforeach;
				?>
			</table>
			</div>
			
			<div id="box_bottom">
				<table cellpadding="0" cellspacing="0" border="0" width="100%">
					<tr>
						<td align="left">
							<img src="<?php echo $templatePath;?>img/box_bottom_left.png" width="5" height="18" alt="" border="0" /><br />
						</td>
						<td align="left">
							<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="9" alt="" border="0" /><br />
						</td>
						<td align="right">
							<img src="<?php echo $templatePath;?>img/box_bottom_right.png" width="5" height="18" alt="" border="0" /><br />
						</td>
					</tr>
				</table>
			</div>
			<?php }?>
			
		</td>
	</tr>
</table>
</form>
